@@ -181,6 +181,19 @@ Int64::set_value(dods_int64 i)
     return true;
 }
 
+unsigned int
+Int64::buf2val(void **val)
+{
+    if (!val)
+        throw InternalErr(__FILE__, __LINE__, "NULL pointer.");
+
+    if (!*val)
+        *val = new dods_int64;
+
+    *(dods_int64 *)*val = d_buf;
+
+    return width();
+}
 void Int64::print_val(ostream &out, string space, bool print_decl_p)
 {
     if (print_decl_p) {
