@@ -268,25 +268,25 @@ UInt32::ops(BaseType *b, int op)
 
     switch (b->type()) {
         case dods_int8_c:
-            return USCmp<dods_uint32, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
+            return Cmp<dods_uint32, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
         case dods_byte_c:
             return Cmp<dods_uint32, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
         case dods_int16_c:
-            return USCmp<dods_uint32, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
+            return Cmp<dods_uint32, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
         case dods_uint16_c:
             return Cmp<dods_uint32, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
         case dods_int32_c:
-            return USCmp<dods_uint32, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
+            return Cmp<dods_uint32, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
         case dods_uint32_c:
             return Cmp<dods_uint32, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
         case dods_int64_c:
-            return USCmp<dods_uint32, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
+            return Cmp<dods_uint32, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
         case dods_uint64_c:
             return Cmp<dods_uint32, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
         case dods_float32_c:
-            return USCmp<dods_uint32, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
+            return Cmp<dods_uint32, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
         case dods_float64_c:
-            return USCmp<dods_uint32, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+            return Cmp<dods_uint32, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
         default:
             return false;
     }
